"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeCodePush = _interopRequireDefault(require("react-native-code-push"));

var _CodePushProvider = require("./CodePushProvider");

var _reactNativeSafeAreaContext = require("react-native-safe-area-context");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const SplashView = ({
  label,
  labelStyle,
  logoSource,
  logoStyle
}) => /*#__PURE__*/_react.default.createElement(_reactNativeSafeAreaContext.SafeAreaView, {
  style: styles.container
}, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
  style: styles.logoContainer
}, logoSource ? /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
  source: logoSource,
  style: logoStyle
}) : null), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
  style: styles.labelContainer
}, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
  style: [styles.label, labelStyle]
}, label)));

const CodePushSplashScreen = ({
  children,
  LoadingComponent,
  ErrorComponent,
  loadingText = 'Checking for updates...',
  errorText = 'There was an error when checking for updates.',
  continueOnError = true,
  timeout
}) => {
  const {
    status
  } = (0, _CodePushProvider.useCodePush)();
  const [timedOut, setTimedOut] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    if (timeout && timeout > 0) {
      const timerId = setTimeout(() => {
        setTimedOut(true);
      }, timeout);
      return () => clearTimeout(timerId);
    }

    return;
  }, [timeout]); // continue on timeout

  if (timedOut) {
    return children;
  }

  switch (status) {
    case _reactNativeCodePush.default.SyncStatus.UP_TO_DATE: // The app is fully up-to-date with the configured deployment.

    case _reactNativeCodePush.default.SyncStatus.UPDATE_INSTALLED: // An available update has been installed and will be run either immediately after the syncStatusChangedCallback function returns or the next time the app resumes/restarts, depending on the InstallMode specified in SyncOptions.

    case _reactNativeCodePush.default.SyncStatus.UPDATE_IGNORED:
      // The app has an optional update, which the end user chose to ignore. (This is only applicable when the updateDialog is used)
      setTimedOut(true);
      break;

    case _reactNativeCodePush.default.SyncStatus.UNKNOWN_ERROR:
      // The sync operation encountered an unknown error.
      if (continueOnError) {
        return children;
      }

      return ErrorComponent !== null && ErrorComponent !== void 0 ? ErrorComponent : /*#__PURE__*/_react.default.createElement(SplashView, {
        label: errorText
      });

    case _reactNativeCodePush.default.SyncStatus.SYNC_IN_PROGRESS: // There is an ongoing sync operation running which prevents the current call from being executed.

    case _reactNativeCodePush.default.SyncStatus.CHECKING_FOR_UPDATE: // The CodePush server is being queried for an update.

    case _reactNativeCodePush.default.SyncStatus.AWAITING_USER_ACTION: // An update is available, and a confirmation dialog was shown to the end user. (This is only applicable when the updateDialog is used)

    case _reactNativeCodePush.default.SyncStatus.DOWNLOADING_PACKAGE: // An available update is being downloaded from the CodePush server.

    case _reactNativeCodePush.default.SyncStatus.INSTALLING_UPDATE:
      // An available update was downloaded and is about to be installed.
      return LoadingComponent !== null && LoadingComponent !== void 0 ? LoadingComponent : /*#__PURE__*/_react.default.createElement(SplashView, {
        label: loadingText
      });
  } // by default show splash without any CodePush status messages


  return LoadingComponent !== null && LoadingComponent !== void 0 ? LoadingComponent : /*#__PURE__*/_react.default.createElement(SplashView, null);
};

const styles = _reactNative.StyleSheet.create({
  container: { ..._reactNative.StyleSheet.absoluteFillObject
  },
  logoContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center'
  },
  labelContainer: {
    padding: 12
  },
  label: {
    textAlign: 'center'
  }
});

var _default = CodePushSplashScreen;
exports.default = _default;
//# sourceMappingURL=CodePushSplashScreen.js.map